searchData={"items":[{"type":"module","title":"LumaaiEx","doc":"A client library for the Luma Labs API using HTTPoison.\n\nThis module provides a high-level interface for interacting with the Luma Labs API,\nincluding functions for authentication, making requests, and handling common operations.","ref":"LumaaiEx.html"},{"type":"function","title":"LumaaiEx.create_generation/2","doc":"Creates a new generation.\n\nThis function sends a request to the Luma Labs API to create a new video generation\nbased on the provided parameters.","ref":"LumaaiEx.html#create_generation/2"},{"type":"function","title":"Parameters - LumaaiEx.create_generation/2","doc":"- config: A `LumaaiEx.Config` struct containing API configuration.\n  - params: A map of parameters for the generation. This can include:\n    - prompt: A string describing the desired video content.\n    - keyframes: A map of keyframes for image-to-video generation.\n    - loop: A boolean indicating whether the video should loop.\n    - aspect_ratio: A string specifying the desired aspect ratio (e.g., \"16:9\").","ref":"LumaaiEx.html#create_generation/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.create_generation/2","doc":"- `{:ok, response}` on success, where `response` is a map containing the generation details.\n  - `{:error, reason}` on failure, where `reason` is a map containing error details.","ref":"LumaaiEx.html#create_generation/2-returns"},{"type":"function","title":"Examples - LumaaiEx.create_generation/2","doc":"config = LumaaiEx.new(auth_token: \"your_api_key\")\n    params = %{\n      prompt: \"A tiger walking in snow\",\n      keyframes: %{\n        frame0: %{\n          type: \"image\",\n          url: \"https://example.com/tiger.jpg\"\n        }\n      },\n      loop: false,\n      aspect_ratio: \"16:9\"\n    }\n    case LumaaiEx.create_generation(config, params) do\n      {:ok, generation} ->\n        IO.puts(\"Generation created with ID: \" <> generation[\"id\"])\n      {:error, reason} ->\n        IO.puts(\"Error creating generation: \" <> inspect(reason))\n    end","ref":"LumaaiEx.html#create_generation/2-examples"},{"type":"function","title":"LumaaiEx.delete_generation/2","doc":"Deletes a specific generation.","ref":"LumaaiEx.html#delete_generation/2"},{"type":"function","title":"Parameters - LumaaiEx.delete_generation/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - id: The ID of the generation to delete.","ref":"LumaaiEx.html#delete_generation/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.delete_generation/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.html#delete_generation/2-returns"},{"type":"function","title":"Examples - LumaaiEx.delete_generation/2","doc":"iex> client = LumaaiEx.new()\n    iex> {:ok, _} = LumaaiEx.delete_generation(client, \"d1968551-6113-4b46-b567-09210c2e79b0\")","ref":"LumaaiEx.html#delete_generation/2-examples"},{"type":"function","title":"LumaaiEx.get_camera_motions/1","doc":"Retrieves available camera motions.","ref":"LumaaiEx.html#get_camera_motions/1"},{"type":"function","title":"Parameters - LumaaiEx.get_camera_motions/1","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.","ref":"LumaaiEx.html#get_camera_motions/1-parameters"},{"type":"function","title":"Returns - LumaaiEx.get_camera_motions/1","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.html#get_camera_motions/1-returns"},{"type":"function","title":"Examples - LumaaiEx.get_camera_motions/1","doc":"iex> client = LumaaiEx.new()\n    iex> {:ok, supported_camera_motions} = LumaaiEx.get_camera_motions(client)","ref":"LumaaiEx.html#get_camera_motions/1-examples"},{"type":"function","title":"LumaaiEx.get_credits/1","doc":"Get the number of credits available for the account.","ref":"LumaaiEx.html#get_credits/1"},{"type":"function","title":"Examples - LumaaiEx.get_credits/1","doc":"iex> client = LumaaiEx.new()\n    iex> LumaaiEx.get_credits(client)\n    {:ok, %{\"credits\" => 100}}","ref":"LumaaiEx.html#get_credits/1-examples"},{"type":"function","title":"LumaaiEx.get_generation/2","doc":"Retrieves a specific generation.","ref":"LumaaiEx.html#get_generation/2"},{"type":"function","title":"Parameters - LumaaiEx.get_generation/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - id: The ID of the generation to retrieve.","ref":"LumaaiEx.html#get_generation/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.get_generation/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.html#get_generation/2-returns"},{"type":"function","title":"Examples - LumaaiEx.get_generation/2","doc":"iex> client = LumaaiEx.new()\n    iex> {:ok, generation} = LumaaiEx.get_generation(client, \"d1968551-6113-4b46-b567-09210c2e79b0\")","ref":"LumaaiEx.html#get_generation/2-examples"},{"type":"function","title":"LumaaiEx.list_generations/2","doc":"Lists generations.","ref":"LumaaiEx.html#list_generations/2"},{"type":"function","title":"Parameters - LumaaiEx.list_generations/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - params: Optional query parameters (default: %{}).","ref":"LumaaiEx.html#list_generations/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.list_generations/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.html#list_generations/2-returns"},{"type":"function","title":"Examples - LumaaiEx.list_generations/2","doc":"iex> client = LumaaiEx.new()\n    iex> {:ok, generations} = LumaaiEx.list_generations(client, limit: 100, offset: 0)","ref":"LumaaiEx.html#list_generations/2-examples"},{"type":"function","title":"LumaaiEx.new/1","doc":"Creates a new LumaaiEx client configuration.","ref":"LumaaiEx.html#new/1"},{"type":"function","title":"Examples - LumaaiEx.new/1","doc":"# Using the LUMAAI_API_KEY environment variable\n    iex> System.put_env(\"LUMAAI_API_KEY\", \"your_api_key\")\n    iex> LumaaiEx.new()\n    %LumaaiEx.Config{auth_token: \"your_api_key\", base_url: \"https://api.lumalabs.ai\"}\n\n    # Explicitly providing the auth_token\n    iex> LumaaiEx.new(auth_token: \"your_api_key\")\n    %LumaaiEx.Config{auth_token: \"your_api_key\", base_url: \"https://api.lumalabs.ai\"}\n\n    # Overriding the base URL\n    iex> LumaaiEx.new(auth_token: \"your_api_key\", base_url: \"https://custom-api.example.com\")\n    %LumaaiEx.Config{auth_token: \"your_api_key\", base_url: \"https://custom-api.example.com\"}","ref":"LumaaiEx.html#new/1-examples"},{"type":"function","title":"LumaaiEx.ping/1","doc":"Pings the Luma Labs API to check connectivity.","ref":"LumaaiEx.html#ping/1"},{"type":"function","title":"Examples - LumaaiEx.ping/1","doc":"iex> client = LumaaiEx.new()\n    iex> LumaaiEx.ping(client)\n    {:ok, %{\"message\" => \"pong\"}}","ref":"LumaaiEx.html#ping/1-examples"},{"type":"module","title":"LumaaiEx.Client","doc":"HTTP client for making requests to the Luma Labs API.\n\nThis module provides a low-level interface for sending HTTP requests\nto the Luma Labs API. It handles authentication and basic error handling.","ref":"LumaaiEx.Client.html"},{"type":"function","title":"LumaaiEx.Client.request/6","doc":"Sends a request to the Luma Labs API.","ref":"LumaaiEx.Client.html#request/6"},{"type":"function","title":"Parameters - LumaaiEx.Client.request/6","doc":"- config: A `LumaaiEx.Config` struct containing API configuration.\n  - method: The HTTP method as an atom (e.g., :get, :post).\n  - path: The API endpoint path.\n  - body: The request body (default: \"\").\n  - headers: Additional headers (default: []).\n  - opts: Additional options for HTTPoison (default: []).","ref":"LumaaiEx.Client.html#request/6-parameters"},{"type":"function","title":"Returns - LumaaiEx.Client.request/6","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.Client.html#request/6-returns"},{"type":"module","title":"LumaaiEx.Config","doc":"Configuration for the LumaaiEx client.\n\nThis module defines the configuration structure used by the LumaaiEx client\nand provides functions to create a new configuration.","ref":"LumaaiEx.Config.html"},{"type":"function","title":"LumaaiEx.Config.new/1","doc":"Creates a new LumaaiEx configuration.\n\nThis function will attempt to retrieve the auth token in the following order:\n1. From the provided `auth_token` option\n2. From the LUMAAI_API_KEY environment variable\n3. If neither is available, it will raise an error","ref":"LumaaiEx.Config.html#new/1"},{"type":"function","title":"Parameters - LumaaiEx.Config.new/1","doc":"- opts: Options for configuration (default: []).\n    - :auth_token - Explicitly provide an auth token\n    - :base_url - Override the default base URL","ref":"LumaaiEx.Config.html#new/1-parameters"},{"type":"function","title":"Returns - LumaaiEx.Config.new/1","doc":"A `LumaaiEx.Config` struct.","ref":"LumaaiEx.Config.html#new/1-returns"},{"type":"function","title":"Examples - LumaaiEx.Config.new/1","doc":"iex> LumaaiEx.Config.new(auth_token: \"your_api_key\")\n    %LumaaiEx.Config{auth_token: \"your_api_key\", base_url: \"https://api.lumalabs.ai\"}\n\n    iex> System.put_env(\"LUMAAI_API_KEY\", \"env_api_key\")\n    iex> LumaaiEx.Config.new()\n    %LumaaiEx.Config{auth_token: \"env_api_key\", base_url: \"https://api.lumalabs.ai\"}\n\n    iex> LumaaiEx.Config.new(base_url: \"https://custom-api.example.com\")\n    %LumaaiEx.Config{auth_token: \"env_api_key\", base_url: \"https://custom-api.example.com\"}","ref":"LumaaiEx.Config.html#new/1-examples"},{"type":"type","title":"LumaaiEx.Config.t/0","doc":"","ref":"LumaaiEx.Config.html#t:t/0"},{"type":"module","title":"LumaaiEx.Generation","doc":"Functions for interacting with the Luma Labs Generation API.\n\nThis module provides high-level functions for creating, listing, retrieving,\nand deleting generations, as well as fetching available camera motions.","ref":"LumaaiEx.Generation.html"},{"type":"function","title":"LumaaiEx.Generation.create/2","doc":"Creates a new generation.","ref":"LumaaiEx.Generation.html#create/2"},{"type":"function","title":"Parameters - LumaaiEx.Generation.create/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - params: A map of parameters for the generation.","ref":"LumaaiEx.Generation.html#create/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.Generation.create/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.Generation.html#create/2-returns"},{"type":"function","title":"LumaaiEx.Generation.delete/2","doc":"Deletes a specific generation.","ref":"LumaaiEx.Generation.html#delete/2"},{"type":"function","title":"Parameters - LumaaiEx.Generation.delete/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - id: The ID of the generation to delete.","ref":"LumaaiEx.Generation.html#delete/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.Generation.delete/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.Generation.html#delete/2-returns"},{"type":"function","title":"LumaaiEx.Generation.get/2","doc":"Retrieves a specific generation.","ref":"LumaaiEx.Generation.html#get/2"},{"type":"function","title":"Parameters - LumaaiEx.Generation.get/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - id: The ID of the generation to retrieve.","ref":"LumaaiEx.Generation.html#get/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.Generation.get/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.Generation.html#get/2-returns"},{"type":"function","title":"LumaaiEx.Generation.get_camera_motions/1","doc":"Retrieves available camera motions.","ref":"LumaaiEx.Generation.html#get_camera_motions/1"},{"type":"function","title":"Parameters - LumaaiEx.Generation.get_camera_motions/1","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.","ref":"LumaaiEx.Generation.html#get_camera_motions/1-parameters"},{"type":"function","title":"Returns - LumaaiEx.Generation.get_camera_motions/1","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.Generation.html#get_camera_motions/1-returns"},{"type":"function","title":"LumaaiEx.Generation.list/2","doc":"Lists generations.","ref":"LumaaiEx.Generation.html#list/2"},{"type":"function","title":"Parameters - LumaaiEx.Generation.list/2","doc":"- client: A `LumaaiEx.Config` struct containing API configuration.\n  - params: Optional query parameters (default: %{}).","ref":"LumaaiEx.Generation.html#list/2-parameters"},{"type":"function","title":"Returns - LumaaiEx.Generation.list/2","doc":"- `{:ok, response}` on success.\n  - `{:error, reason}` on failure.","ref":"LumaaiEx.Generation.html#list/2-returns"},{"type":"extras","title":"LumaaiEx","doc":"# LumaaiEx\n\n\nA client library for the Luma Labs API, providing a simple and intuitive interface for Elixir applications to interact with Luma Labs services.","ref":"readme.html"},{"type":"extras","title":"Installation - LumaaiEx","doc":"Add `lumaai_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:lumaai_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - LumaaiEx","doc":"To use the Luma Labs API, you need an API key. Sign up for an account on the [Luma Labs website](https://lumalabs.ai/) to obtain your key.","ref":"readme.html#usage"},{"type":"extras","title":"Authentication - LumaaiEx","doc":"1. Get a key from https://lumalabs.ai/dream-machine/api/keys\n2. Pass it to the client SDK by either:\n   1. Setting the `LUMAAI_API_KEY` environment variable\n   2. Passing `auth_token` to the client","ref":"readme.html#authentication"},{"type":"extras","title":"Setting up the client - LumaaiEx","doc":"Using `LUMAAI_API_KEY` env variable:\n\n```elixir\nclient = LumaaiEx.new()\n```\n\nUsing `auth_token` parameter:\n\n```elixir\nclient = LumaaiEx.new(auth_token: System.get_env(\"LUMAAI_API_KEY\"))\n```","ref":"readme.html#setting-up-the-client"},{"type":"extras","title":"Making API calls - LumaaiEx","doc":"#### Create a new text-to-video generation\n\n```elixir\n{:ok, generation} = LumaaiEx.create_generation(client, %{\n  prompt: \"A teddy bear in sunglasses playing electric guitar and dancing\"\n})\n```\n\n#### Create a generation with loop and aspect ratio\n\n```elixir\n{:ok, generation} = LumaaiEx.create_generation(client, %{\n  prompt: \"A teddy bear in sunglasses playing electric guitar and dancing\",\n  loop: true,\n  aspect_ratio: \"3:4\"\n})\n```\n\n#### Create an image-to-video generation with a start frame\n\n```elixir\n{:ok, generation} = LumaaiEx.create_generation(client, %{\n  prompt: \"Low-angle shot of a majestic tiger prowling through a snowy landscape, leaving paw prints on the white blanket\",\n  keyframes: %{\n    frame0: %{\n      type: \"image\",\n      url: \"https://storage.cdn-luma.com/dream_machine/7e4fe07f-1dfd-4921-bc97-4bcf5adea39a/video_0_thumb.jpg\"\n    }\n  }\n})\n```\n\n#### Extend a video\n\n```elixir\n{:ok, generation} = LumaaiEx.create_generation(client, %{\n  prompt: \"A teddy bear in sunglasses playing electric guitar and dancing\",\n  keyframes: %{\n    frame0: %{\n      type: \"generation\",\n      id: \"d1968551-6113-4b46-b567-09210c2e79b0\"\n    }\n  }\n})\n```\n\n#### Get a specific generation\n\n```elixir\n{:ok, generation} = LumaaiEx.get_generation(client, \"d1968551-6113-4b46-b567-09210c2e79b0\")\n```\n\n#### List all generations\n\n```elixir\n{:ok, generations} = LumaaiEx.list_generations(client, limit: 100, offset: 0)\n```\n\n#### Delete a generation\n\n```elixir\n{:ok, _} = LumaaiEx.delete_generation(client, \"d1968551-6113-4b46-b567-09210c2e79b0\")\n```\n\n#### Get available camera motions\n\n```elixir\n{:ok, supported_camera_motions} = LumaaiEx.get_camera_motions(client)\n```\n\n#### Create a generation with a callback URL\n\n```elixir\n{:ok, generation} = LumaaiEx.create_generation(client, %{\n  prompt: \"A teddy bear in sunglasses playing electric guitar and dancing\",\n  callback_url: \"https://your-api-endpoint.com/callback\"\n})\n```","ref":"readme.html#making-api-calls"},{"type":"extras","title":"How to get the video for a generation - LumaaiEx","doc":"Right now, the only supported way is via polling. The create endpoint returns an id which is a UUID V4. You can use it to poll for updates (you can see the video at `generation.assets.video`).\n\n```elixir\ndefmodule GenerationPoller do\n  def poll_until_completed(client, generation_id) do\n    case LumaaiEx.get_generation(client, generation_id) do\n      {:ok, %{state: \"completed\", assets: %{video: video_url}}} ->\n        {:ok, video_url}\n      {:ok, %{state: \"failed\", failure_reason: reason}} ->\n        {:error, \"Generation failed: #{reason}\"}\n      {:ok, _} ->\n        IO.puts(\"Dreaming...\")\n        Process.sleep(3000)\n        poll_until_completed(client, generation_id)\n      {:error, reason} ->\n        {:error, reason}\n    end\n  end\nend\n\n{:ok, generation} = LumaaiEx.create_generation(client, %{\n  prompt: \"A teddy bear in sunglasses playing electric guitar and dancing\"\n})\n\ncase GenerationPoller.poll_until_completed(client, generation.id) do\n  {:ok, video_url} ->\n    # Download the video\n    {:ok, %HTTPoison.Response{body: body}} = HTTPoison.get(video_url)\n    File.write!(\"#{generation.id}.mp4\", body)\n    IO.puts(\"File downloaded as \" <> generation.id <> \".mp4\")\n  {:error, reason} ->\n    IO.puts(\"Error: \" <> reason)\nend\n```\n\nFor more information on available endpoints and parameters, refer to the [Luma Labs API documentation](https://docs.lumalabs.ai/docs/api).","ref":"readme.html#how-to-get-the-video-for-a-generation"},{"type":"extras","title":"Documentation - LumaaiEx","doc":"Full documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc). After installing it, run:\n\n```\nmix docs\n```","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - LumaaiEx","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing"},{"type":"extras","title":"License - LumaaiEx","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [0.1.0](https://github.com/vitalis/lumaai_ex/compare/0.1.0...0.1.0) (2024-10-17)","ref":"changelog.html"},{"type":"extras","title":"chore: - Changelog","doc":"* GitOps: Add changelog using git_ops.\n\n* release version 0.1.0","ref":"changelog.html#chore"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}